## 1.1.1

New APIs for JavaScript and TypeScript to support bug fixing and `Object3D.clone()` to
unlock new use cases.

### Destruction Safety

Previously it was possible, but prohibited, to access destroyed objects. If you did so
anyway, you would get a wide range of errors. With this version we provide clear errors
when accessing destroyed `Object3D`, `Texture` and custom `Component` instances, when
switched on:

```js
engine.erasePrototypeOnDestroy = true;

const obj = engine.scene.addObject();
obj.name = 'iamalive';
console.log(obj.name); // Prints 'iamalive'

obj.destroy();
console.log(obj.name); // Throws an error
```

This behavior is going to be enabled by default starting with 1.2.0.

### Changelog

**Editor**

- Added "pending auth" text for connected Android devices that need to authenticate USB debugging
- Added a checkbox for launching `https://localhost` when SSL certificates are set up
- Added offset rotation and translation properties to physx component
- Added support for dropping multiple files from Asset Browser for import
- Exposed texture streaming settings for control over texture streaming performance budgets
- Fixed Command + S switching to scaling Gizmo on MacOS
- Fixed DPI scaling not updating when UI scaling changes on windows
- Fixed DPI scaling not updating when moving the Editor to a Retina display
- Fixed a crash when encountering a JSON parsing error in a `package.json` in `node_modules`
- Fixed crash when changing material property type in a custom shader
- Fixed project's id generator type not being applied for resources created during project load
- Made quick launch to Wolvic Browser agnostic of connected headset manufacturer

**Engine**

- Now skipping rendering to empty views (fixes issue with WebXR Emulator Browser extensions)
- Added support for PhysX shape "local pose" via offset transform

**Runtime**

- Fixed various rendering errors related to unusual view setups and active states
- Now resuming `window.requestAnimationFrame()` after XR session ended (workaround for issue with
  WebXR Emulator Browser extensions)

**JavaScript/TypeScript API**

- `Object3D`, `Texture` and custom JavaScript `Component` instances now get their prototype
  replaced on `.destroy()`, if you set `engine.erasePrototypeOnDestroy = true`.
- Added `Object3D.isDestroyed`
- Added `PhysXComponent.setTranslationOffset`, `PhysXComponent.getTranslationOffset`,
  `get/set PhysXComponent.translationOffset` and `get/set PhysXComponent.rotationOffset`.
- Added support for `Scene.load()` from `ArrayBuffer`
- Added `Object3D.clone()` to clone hierarchies with components and `Component.copy()`
